import notify2
from location import get_location
from weather import get_weather


def notify():

    icon_path = "/home/dushyant/Desktop/Github/Weather-Notifier/weathernotifier/Weather-icon.png"

    place = get_location()
    resp = get_weather(place)

    print resp

    result = ''
    result += "Place : " + str(resp[0]["Place"])
    result += "\nStatus : " + str(resp[6])
    result += "\nCurrent Temperature (Celcius) : " + str(resp[1]["temp"])
    result += "\nMax Temperature (Celcius) : " + str(resp[1]["temp_max"])
    result += "\nMin Temperature (Celcius) : " + str(resp[1]["temp_min"])
    result += "\nWind Speed (m/s) : " + str(resp[2]["speed"])
    result += "\nHumidity (%) : " + str(resp[3])
    result += "\nPressure (hpa) : " + str(resp[4]["press"])
    result += "\nCloud Cover (%) : " + str(resp[5])

    # print result

    # Notification Tool

    notify2.init("Weather Notifier")
    n = notify2.Notification("Weather Details", icon=icon_path)
    n.update("Weather Details", result)
    n.show()


if __name__ == '__main__':
    notify()


import reverse_geocoder as rg
import requests
import json


def get_location():
    API_KEY = "7efb02dc0ba8ee84f6f63945578cdcca"
    request_url = "http://api.ipstack.com/check?access_key={}".format(API_KEY)
    r = requests.get(request_url)
    j = json.loads(r.text)
    # print j
    lat = j['latitude']
    lon = j['longitude']

    print lat
    print lon

    results = rg.search((lat,lon))

    return results[0]["name"]





import pyowm
from location import get_location


def get_weather(location):

    # location = get_location()
    #
    # print location

    owm = pyowm.OWM('a4c44b228e720ea728b757f3aa754c06') # API Key
    observation = owm.weather_at_place(location)

    dic ={}
    dic["Place"] = location

    w = observation.get_weather()

    l=[]
    l.append(dic)
    l.append(w.get_temperature('celsius'))
    l.append(w.get_wind())
    l.append(w.get_humidity())
    l.append(w.get_pressure())
    l.append(w.get_clouds())
    l.append(w.get_status())
    l.append(w.get_sunrise_time('iso'))
    l.append(w.get_sunset_time('iso'))

    # print l

    return l

# get_weather()





#!/usr/bin/env python

from setuptools import setup

setup(
    name='weather-notify',
    version='1.0.0',
    description='Shows weather details',
    long_description='This python package initiates a notification tool displaying the weather details of user\'s location',
    author='Dushyant Rathore',
    license='MIT',
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stablegit
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Intended Audience :: Information Technology',
        'Natural Language :: English',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5'
    ],
    keywords = "Weather notification tool",
    author_email='dushyant.bgs@gmail.com',
    url='https://github.com/dushyantRathore/Weather-Notifier',
    packages=['weathernotifier'],
    install_requires=[
        "reverse_geocoder",
        "requests==2.18.2",
        "pyowm",
        "notify2"
    ],
    entry_points={
        'console_scripts':
            ['weathernotifier = weathernotifier.notifier:notify']
    }
)